@@ -122,6 +122,7 @@ class DetectSequence(Base):
     def _load_models(self, sequences):
         if not sequences:
             sequences = self.model_sequence
+        self.logger.Debug (3, "load_models: {}".format(sequences))
         for seq in sequences:
             if seq == 'object':
                 self.models[seq] = []
@@ -317,7 +318,7 @@ class DetectSequence(Base):
         
 
         start = datetime.datetime.now()
-        media = MediaStream(stream,'video', self.stream_options )
+        media = MediaStream(stream,'video', self.stream_options, logger=self.logger )
         self.media = media
 
         polygons = self.stream_options.get('polygons',[])
@@ -354,7 +355,8 @@ class DetectSequence(Base):
                     try:
                         self._load_models([seq])
                         if manual_locking:
-                            self.models[seq].acquire_lock()
+                            for m in self.models[seq]:
+                                m.acquire_lock()
                     except Exception as e:
                         self.logger.Error('Error loading model for {}:{}'.format(seq,e))
                         self.logger.Debug(2,traceback.format_exc())
@@ -443,10 +445,10 @@ class DetectSequence(Base):
                 matched_frame_img = matched_images[idx]
        
         if manual_locking:
-            if self.face_model:
-                self.face_model.release_lock()
-            if self.object_model:
-                self.object_model.release_lock()
+            for seq in self.model_sequence:
+                for m in self.models[seq]:
+                    m.release_lock()
+            
         self.logger.Debug(
             1,'detection (with image loads) took: {} milliseconds to process {}'.format(diff_time, stream))
         self.media.stop()
@@ -461,6 +463,8 @@ class DetectSequence(Base):
             #'type': matched_type,
             'image': matched_frame_img
         }
+        # if invoked again, we need to resize polys
+        self.has_rescaled = False
         return matched_data, all_matches
 
 
